/*
 * Copyright (c), Lawrence Foard, 1992
 *
 * Developed under contract by Virtual World Information systems.
 * Questions and suggestions about this package may be directed to:
 * lfoard@turing.org, entropy@world.std.com
 * 
 * Those without e-mail access can call the VWIS Linux support BBS
 * at 1-508-793-9568 and send e-mail to entropy,
 * or send snail mail to:
 *
 * Virtual World Information Systems
 * 217 Park Ave.
 * Box #108
 * Worcester MA 01609
 *
 * This code may be used under the terms of the GNU license.
 * Other licensing agreements may be negotiated with VWIS.
 *
 */

#define VERSION "0.1 (alpha test)"

typedef struct process PROCESS;
typedef struct remap REMAP;


struct process
 {
  char *prog_area;
  int prog_size;
  int seg_break;
  int user_stack;
  int nargs;
  int handlers[32];
  unsigned int restorer; /* restore routine for signal */
  char *effective_root;
  REMAP *map; /* file name remapping */
  FILE *debug;
 };

struct remap
 {
  char *prefix;
  char *replace;
  REMAP *next;
 };

/* top of stack containing registers during "system call" */
struct registers
 { 
  unsigned int eax;
  unsigned int ebx;
  unsigned int ecx;
  unsigned int edx;
  unsigned int esi;
  unsigned int edi;
  unsigned int ebp;
  unsigned int flags;
  unsigned int eip;
  unsigned int cs;
 };

/* top of stack containing registers and arguments */
struct stack_top
 { 
  struct registers regs;
  unsigned int junk;
  unsigned int stack[10];
 };

#define FLAG_CF 1
#define CLEAR_CARRY(regs) ((regs)->flags&=~FLAG_CF)
#define SET_CARRY(regs) ((regs)->flags|=FLAG_CF)

/* default stack and heap size */
#define HEAP_SIZE  (4*1024*1024)
#define STACK_SIZE (4*1024*1024)

PROCESS *load_file(char *file,FILE *debug,int stack_size,int heap_size);
void set_argvnc(PROCESS *process,char *argv[],char *envp[]);
void add_map(PROCESS *process,char *prefix,char *replace);
char *fixfile(PROCESS *process,char *name);
void set_segments(PROCESS *proc);
int do_ioctl(PROCESS *proc,unsigned int fd,int command,int data);
int do_fcntl(PROCESS *proc,int fd,unsigned int command,int data);
int set_sig(int num,int loc);
